@@ -147,13 +147,13 @@ def get_payfonetrust_mappings():
 
 
 def get_bokugpir_mappings():
-    return get_mappings_in_out('boku_gpir', 'boku_gpir_payload.xml', 'getPhoneIdentificationResult',
-                               'boku_gpir_out', 'boku_gpir_to_sas.xml', 'bokugpirRespToOde')
+    return get_mappings_in_out('bokugpir', 'boku_gpir_payload.xml', 'getPhoneIdentificationResult',
+                               'bokugpir_out', 'boku_gpir_to_sas.xml', 'bokugpirRespToOde')
 
 
 def get_bokumaa_mappings():
-    return get_mappings_in_out('boku_maa', 'boku_maa_payload.xml', 'matchAndAttributes',
-                               'boku_maa_out', 'boku_maa_to_sas.xml', 'bokumaaRespToOde')
+    return get_mappings_in_out('bokumaa', 'boku_maa_payload.xml', 'matchAndAttributes',
+                               'bokumaa_out', 'boku_maa_to_sas.xml', 'bokumaaRespToOde')
 
 
 def get_socure_mappings():
@@ -194,8 +194,8 @@ def get_mapping_choices():
 
 
 def add_mapping_in_str(str_map_to, str_map_from, enrichment_name, include_default=True):
-    map_to_enrichment = json.load(str_map_to)
-    map_from_enrichment = json.load(str_map_from)
+    map_to_enrichment = json.loads(str_map_to)
+    map_from_enrichment = json.loads(str_map_from)
     return add_mapping(map_to_enrichment, map_from_enrichment, enrichment_name, include_default)
 
 # to_map = {'UniqueId': 'uniqueId', 'username': 'user_name'}
