@@ -9,7 +9,10 @@ def set_default_targets(http_url=None, http_port=None):
     global enrich_targets
     starthttp = 'http://localhost:8100/'
     if http_url is not None and http_port is not None:
-        starthttp = 'http://' + http_url + ':' + http_port + '/'
+        if isinstance(http_port, int):
+            starthttp = 'http://' + http_url + ':' + str(http_port) + '/'
+        else:
+            starthttp = 'http://' + http_url + ':' + http_port + '/'
         
     enrich_targets = {
         'socure': {
@@ -39,6 +42,14 @@ def set_default_targets(http_url=None, http_port=None):
             'url': starthttp + 'giact/items',
             'mechanism': 'GET'
         },
+        'datavisor': {
+            'url': starthttp + 'datavisor/items',
+            'mechanism': 'GET'
+        },
+        'iovation': {
+            'url': starthttp + 'iovation/items',
+            'mechanism': 'GET'
+        },
         # TODO - need to check on payfone site for details if different than ID360/boss
         'payfonetrust': {
             'url': starthttp + 'payfone/trust/v2',
