@@ -65,8 +65,11 @@ def convert_to_sas(enrichment_returned_data_dict, mappings):
                         val2 = int(val2 is True)
                     out_dictionary[out_sas_key] = val2
                 except:
-                    #add_outstr('value not found for %s' % out_sas_key)
-                    # Do nothing at the moment
-                    print()
+                    handleOrIgnoreError(out_sas_key, False)
+
     return out_dictionary
 
+
+def handleOrIgnoreError(out_sas_key, handle=True):
+    if handle:
+        add_outstr('value not found for %s' % out_sas_key)
